@@ -64,9 +64,7 @@ ApplicationNotifier::ApplicationNotifier(QObject* parent)
     init();
 }
 
-ApplicationNotifier::~ApplicationNotifier()
-{
-}
+ApplicationNotifier::~ApplicationNotifier() = default;
 
 void ApplicationNotifier::init()
 {
@@ -132,8 +130,6 @@ void ApplicationNotifier::parseUpdateInfo()
     if (line.isEmpty())
         return;
 
-    m_securityUpdates = 0;
-    m_normalUpdates = 0;
     // Format updates;security
     int eqpos = line.indexOf(';');
 
@@ -143,6 +139,9 @@ void ApplicationNotifier::parseUpdateInfo()
         
         int securityUpdates = securityString.toInt();
         setUpdates(updatesString.toInt() - securityUpdates, securityUpdates);
+    } else {
+        //if the format is wrong consider as up to date
+        setUpdates(0, 0);
     }
 }
 
