@@ -35,22 +35,20 @@ Q_PROPERTY(int startElements MEMBER m_startElements)
 public:
     explicit DummyBackend(QObject* parent = nullptr);
 
-    virtual void setMetaData(const QString& path) override;
-    virtual QList<AbstractResource*> upgradeablePackages() const override;
-    virtual AbstractResource* resourceByPackageName(const QString& name) const override;
-    virtual int updatesCount() const override;
-    virtual AbstractBackendUpdater* backendUpdater() const override;
-    virtual AbstractReviewsBackend* reviewsBackend() const override;
-    virtual QList<AbstractResource*> searchPackageName(const QString& searchText) override;
-    virtual QVector<AbstractResource*> allResources() const override;
-    virtual bool isValid() const override { return true; } // No external file dependencies that could cause runtime errors
-    virtual QList<QAction*> messageActions() const override { return m_messageActions; }
+    void setMetaData(const QString& path) override;
+    AbstractResource* resourceByPackageName(const QString& name) const override;
+    int updatesCount() const override;
+    AbstractBackendUpdater* backendUpdater() const override;
+    AbstractReviewsBackend* reviewsBackend() const override;
+    QList<AbstractResource*> searchPackageName(const QString& searchText) override;
+    QVector<AbstractResource*> allResources() const override;
+    bool isValid() const override { return true; } // No external file dependencies that could cause runtime errors
+    QList<QAction*> messageActions() const override { return m_messageActions; }
 
-    virtual void cancelTransaction(AbstractResource* app) override;
-    virtual void installApplication(AbstractResource* app) override;
-    virtual void installApplication(AbstractResource* app, const AddonList& addons) override;
-    virtual void removeApplication(AbstractResource* app) override;
-    virtual bool isFetching() const override { return m_fetching; }
+    void installApplication(AbstractResource* app) override;
+    void installApplication(AbstractResource* app, const AddonList& addons) override;
+    void removeApplication(AbstractResource* app) override;
+    bool isFetching() const override { return m_fetching; }
 
 public Q_SLOTS:
     void checkForUpdates();
