@@ -21,6 +21,7 @@
 #include "KNSBackendTest.h"
 #include <KNSBackend.h>
 #include <KXmlGuiWindow>
+#include <resources/AbstractBackendUpdater.h>
 #include <resources/AbstractResource.h>
 #include <resources/ResourcesModel.h>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
@@ -42,8 +43,6 @@ KNSBackendTest::KNSBackendTest(QObject* parent)
     ResourcesModel* model = new ResourcesModel(QFINDTESTDATA("knscorrect-backend.desktop"), this);
     Q_ASSERT(!model->backends().isEmpty());
     m_backend = model->backends().at(0);
-    auto m_window = new KXmlGuiWindow();
-    model->integrateMainWindow(m_window);
 
     if (!m_backend->isValid()) {
         qWarning() << "couldn't run the test";
@@ -68,11 +67,30 @@ void KNSBackendTest::testRetrieval()
     QVector<AbstractResource*> resources = m_backend->allResources();
     QVERIFY(!resources.isEmpty());
     QCOMPARE(resources.count(), model->rowCount());
+    QVERIFY(m_backend->backendUpdater());
+    QCOMPARE(m_backend->updatesCount(), m_backend->backendUpdater()->toUpdate().count());
     
     foreach(AbstractResource* res, resources) {
         QVERIFY(!res->name().isEmpty());
         QVERIFY(!res->categories().isEmpty());
         QVERIFY(!res->origin().isEmpty());
+        QVERIFY(!res->icon().isEmpty());
+        QVERIFY(!res->comment().isEmpty());
+        QVERIFY(!res->longDescription().isEmpty());
+//         QVERIFY(!res->license().isEmpty());
+        QVERIFY(res->homepage().isValid() && !res->homepage().isEmpty());
+        QVERIFY(res->state() > AbstractResource::Broken);
+        QVERIFY(res->addonsInformation().isEmpty());
+        QVERIFY(res->thumbnailUrl().isValid() || res->thumbnailUrl().isEmpty());
+        QVERIFY(res->screenshotUrl().isValid() || res->screenshotUrl().isEmpty());
+
+        QSignalSpy spy(res, &AbstractResource::screenshotsFetched);
+        res->fetchScreenshots();
+        QVERIFY(spy.count() || spy.wait());
+
+        QSignalSpy spy1(res, &AbstractResource::changelogFetched);
+        res->fetchChangelog();
+        QVERIFY(spy1.count() || spy1.wait());
     }
 }
 
@@ -80,14 +98,18 @@ void KNSBackendTest::testReviews()
 {
     QVector<AbstractResource*> resources = m_backend->allResources();
     AbstractReviewsBackend* rev = m_backend->reviewsBackend();
+    QVERIFY(!rev->hasCredentials());
     foreach(AbstractResource* res, resources) {
         Rating* r = rev->ratingForApplication(res);
         QVERIFY(r);
         QCOMPARE(r->packageName(), res->packageName());
         QVERIFY(r->rating()>0 && r->rating()<=10);
-//         rev->fetchReviews(res);
-//         QTest::kWaitForSignal(rev, SIGNAL(reviewsReady(AbstractResource*,QList<Review*>)));
     }
+
+    auto res = resources.first();
+    QSignalSpy spy(rev, &AbstractReviewsBackend::reviewsReady);
+    rev->fetchReviews(res);
+    QVERIFY(spy.count() || spy.wait());
 }
 
 void KNSBackendTest::reviewsArrived(AbstractResource* r, const QList< Review* >& revs)
