@@ -40,13 +40,6 @@ PackageKitUpdater::PackageKitUpdater(PackageKitBackend * parent)
     m_percentage(0),
     m_lastUpdate()
 {
-    m_updateAction = new QAction(this);
-    m_updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
-    m_updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
-    m_updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
-    m_updateAction->setEnabled(PackageKit::Daemon::networkState() != PackageKit::Daemon::NetworkOffline);
-    connect(m_updateAction, &QAction::triggered, parent, &PackageKitBackend::refreshDatabase);
-
     fetchLastUpdateTime();
 }
 
@@ -58,7 +51,7 @@ PackageKitUpdater::~PackageKitUpdater()
 void PackageKitUpdater::prepare()
 {
     Q_ASSERT(!m_transaction);
-    m_toUpgrade = m_backend->upgradeablePackages().toSet();
+    m_toUpgrade = m_backend->upgradeablePackages();
     m_allUpgradeable = m_toUpgrade;
 }
 
@@ -118,8 +111,9 @@ void PackageKitUpdater::start()
     setProgressing(true);
 }
 
-void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint )
+void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint time)
 {
+    qDebug() << "update finished!" << exit << time;
     if (exit == PackageKit::Transaction::ExitEulaRequired)
         return;
     disconnect(m_transaction, nullptr, this, nullptr);
@@ -217,14 +211,9 @@ QDateTime PackageKitUpdater::lastUpdate() const
     return m_lastUpdate;
 }
 
-bool PackageKitUpdater::isAllMarked() const
-{
-    return m_toUpgrade.count() >= m_backend->updatesCount();
-}
-
 bool PackageKitUpdater::isCancelable() const
 {
-    return m_transaction->allowCancel();
+    return m_isCancelable;
 }
 
 bool PackageKitUpdater::isProgressing() const
@@ -247,11 +236,6 @@ quint64 PackageKitUpdater::downloadSpeed() const
     return m_speed;
 }
 
-QList<QAction*> PackageKitUpdater::messageActions() const
-{
-    return QList<QAction*>() << m_updateAction;
-}
-
 void PackageKitUpdater::cancel()
 {
     m_transaction->cancel();
@@ -326,6 +310,30 @@ void PackageKitUpdater::itemProgress(const QString& itemID, PackageKit::Transact
     auto res = packagesForPackageId({itemID});
 
     foreach(auto r, res) {
-        resourceProgressed(r, percentage);
+        Q_EMIT resourceProgressed(r, percentage);
+    }
+}
+
+void PackageKitUpdater::fetchChangelog() const
+{
+    QStringList pkgids;
+    foreach(AbstractResource* res, m_allUpgradeable) {
+        pkgids += static_cast<PackageKitResource*>(res)->availablePackageId();
+    }
+    Q_ASSERT(!pkgids.isEmpty());
+
+    PackageKit::Transaction* t = PackageKit::Daemon::getUpdatesDetails(pkgids);
+    connect(t, &PackageKit::Transaction::updateDetail, this, &PackageKitUpdater::updateDetail);
+    connect(t, &PackageKit::Transaction::errorCode, this, &PackageKitUpdater::errorFound);
+}
+
+void PackageKitUpdater::updateDetail(const QString& packageID, const QStringList& updates, const QStringList& obsoletes, const QStringList& vendorUrls,
+                                      const QStringList& bugzillaUrls, const QStringList& cveUrls, PackageKit::Transaction::Restart restart, const QString& updateText,
+                                      const QString& changelog, PackageKit::Transaction::UpdateState state, const QDateTime& issued, const QDateTime& updated)
+{
+    auto res = packagesForPackageId({packageID});
+    foreach(auto r, res) {
+        static_cast<PackageKitResource*>(r)->updateDetail(packageID, updates, obsoletes, vendorUrls, bugzillaUrls,
+                                                          cveUrls, restart, updateText, changelog, state, issued, updated);
     }
 }
